<?php
/**
 * Theme functions and definitions
 *
 * @package kiddiz_center
 */ 


if ( ! function_exists( 'kiddiz_center_enqueue_styles' ) ) :
	/**
	 * Load assets.
	 *
	 * @since 1.0.0
	 */
	function kiddiz_center_enqueue_styles() {
		wp_enqueue_style( 'kiddiz-style-parent', get_template_directory_uri() . '/style.css' );
		wp_enqueue_style( 'kiddiz-center-style', get_stylesheet_directory_uri() . '/style.css', array( 'kiddiz-style-parent' ), '1.0.0' );

		// Add custom fonts, used in the main stylesheet.
        wp_enqueue_style( 'kiddiz-center-fonts', kiddiz_center_fonts_url(), array(), null );
	}
endif;
add_action( 'wp_enqueue_scripts', 'kiddiz_center_enqueue_styles', 99 );

function kiddiz_center_remove_action() {
	remove_action( 'kiddiz_header_start_action', 'kiddiz_header_start', 10 );
	remove_action( 'kiddiz_header_ends_action', 'kiddiz_header_ends', 10 );
	add_action( 'wp_enqueue_scripts', 'kiddiz_center_custom_style', 100 );
	add_action( 'customize_register', 'kiddiz_center_add_control' );
}
add_action( 'init', 'kiddiz_center_remove_action');

function kiddiz_center_add_control( $wp_customize ) {

	// Add header section
	$wp_customize->add_section( 'kiddiz_header_section', array(
		'title'             => esc_html__( 'Header Section','kiddiz-center' ),
		'description'       => esc_html__( 'Header Setting Options', 'kiddiz-center' ),
		'panel'             => 'kiddiz_theme_options_panel',
		'priority'			=> 1,
	) );

	// header bottom wave border enable setting and control.
	$wp_customize->add_setting( 'kiddiz_theme_options[enable_header_wave]', array(
		'default'           => kiddiz_theme_option('enable_header_wave'),
		'sanitize_callback' => 'kiddiz_sanitize_switch',
	) );

	$wp_customize->add_control( new Kiddiz_Switch_Control( $wp_customize, 'kiddiz_theme_options[enable_header_wave]', array(
		'label'             => esc_html__( 'Enable Bottom Cloud Border', 'kiddiz-center' ),
		'section'           => 'kiddiz_header_section',
		'on_off_label' 		=> kiddiz_show_options(),
	) ) );

	// slider top wave border enable setting and control.
	$wp_customize->add_setting( 'kiddiz_theme_options[enable_slider_top_wave]', array(
		'default'           => kiddiz_theme_option('enable_slider_top_wave'),
		'sanitize_callback' => 'kiddiz_sanitize_switch',
	) );

	$wp_customize->add_control( new Kiddiz_Switch_Control( $wp_customize, 'kiddiz_theme_options[enable_slider_top_wave]', array(
		'label'             => esc_html__( 'Enable Top Cloud Border', 'kiddiz-center' ),
		'section'           => 'kiddiz_slider_section',
		'on_off_label' 		=> kiddiz_show_options(),
	) ) );

	// slider wave border enable setting and control.
	$wp_customize->add_setting( 'kiddiz_theme_options[enable_slider_wave]', array(
		'default'           => kiddiz_theme_option('enable_slider_wave'),
		'sanitize_callback' => 'kiddiz_sanitize_switch',
	) );

	$wp_customize->add_control( new Kiddiz_Switch_Control( $wp_customize, 'kiddiz_theme_options[enable_slider_wave]', array(
		'label'             => esc_html__( 'Enable Bottom Cloud Border', 'kiddiz-center' ),
		'section'           => 'kiddiz_slider_section',
		'on_off_label' 		=> kiddiz_show_options(),
	) ) );


	// slider wave color control and setting
	$wp_customize->add_setting( 'kiddiz_theme_options[slider_wave_color]', array(
		'default'           => '#00c2ff',
		'sanitize_callback' => 'sanitize_hex_color', // The hue is stored as a positive integer.
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kiddiz_theme_options[slider_wave_color]', array(
		'label'    => esc_html__( 'Bottom Cloud Border Color', 'kiddiz-center' ),
		'section'  => 'kiddiz_slider_section',
	) ) );

}

if ( ! function_exists( 'kiddiz_center_theme_defaults' ) ) :
    /**
     * Customize theme defaults.
     *
     * @since 1.0.0
     *
     * @param array $defaults Theme defaults.
     * @param array Custom theme defaults.
     */
    function kiddiz_center_theme_defaults( $defaults ) {
        $defaults['enable_header_wave'] = true;
        $defaults['enable_slider_wave'] = true;
        $defaults['enable_slider'] = false;
        $defaults['enable_short_cta'] = false;
        $defaults['enable_service'] = false;
        $defaults['enable_introduction'] = false;
        $defaults['enable_team'] = false;
        $defaults['enable_portfolio'] = false;
        $defaults['enable_cta'] = false;
        $defaults['enable_recent'] = false;
        
        return $defaults;
    }
endif;
add_filter( 'kiddiz_default_theme_options', 'kiddiz_center_theme_defaults', 99 );

/**
 * Enqueue editor styles for Gutenberg
 */
function kiddiz_center_block_editor_styles() {
    // Add custom fonts.
    wp_enqueue_style( 'kiddiz-center-fonts', kiddiz_center_fonts_url(), array(), null );
}
add_action( 'enqueue_block_editor_assets', 'kiddiz_center_block_editor_styles' );

if ( ! function_exists( 'kiddiz_center_fonts_url' ) ) :
/**
 * Register Google fonts
 *
 * @return string Google fonts URL for the theme.
 */
function kiddiz_center_fonts_url() {
    $fonts_url = '';
    $fonts     = array();
    $subsets   = 'latin,latin-ext';

    /* translators: If there are characters in your language that are not supported by Dosis, translate this to 'off'. Do not translate into your own language. */
    if ( 'off' !== _x( 'on', 'Dosis font: on or off', 'kiddiz-center' ) ) {
        $fonts[] = 'Dosis:300,400,500,600,700';
    }

    $query_args = array(
        'family' => urlencode( implode( '|', $fonts ) ),
        'subset' => urlencode( $subsets ),
    );

    if ( $fonts ) {
        $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
    }

    return esc_url_raw( $fonts_url );
}
endif;

// Add class to body.
function kiddiz_center_add_body_class( $classes ) {
    return array_merge( $classes, array( 'header-font-5' ) );
}
add_filter( 'body_class', 'kiddiz_center_add_body_class' );

if ( ! function_exists( 'kiddiz_center_custom_style' ) ) :
	/**
	 * custom css enqueue
	 */
	function kiddiz_center_custom_style() {
		$css = '';

		$slider_wave_color = kiddiz_theme_option( 'slider_wave_color', '#00c2ff' );
		if ( '#56509f' != $slider_wave_color ) {
			$css .= '
			#custom-header .wave-saperator.bottom-wave svg {
				fill: ' . esc_attr( $slider_wave_color ) . ';
			}';
		}

		wp_add_inline_style( 'kiddiz-style', $css );
	}
endif;

if ( ! function_exists( 'kiddiz_center_header_start' ) ) :
	/**
	 * Header starts html codes
	 *
	 * @since Kiddiz 1.0.0
	 */
	function kiddiz_center_header_start() { 
		$sticky_header = kiddiz_theme_option( 'enable_sticky_header' ) ? 'sticky-header' : ''; 
		?>
		<header id="masthead" class="site-header center-align <?php echo esc_attr( $sticky_header ); ?>">
		<div class="wrapper">
	<?php }
endif;
add_action( 'kiddiz_header_start_action', 'kiddiz_center_header_start', 10 );

if ( ! function_exists( 'kiddiz_center_header_ends' ) ) :
	/**
	 * Header ends codes
	 *
	 * @since Kiddiz Pro 1.0.0
	 */
	function kiddiz_center_header_ends() { ?>
		</div><!-- .wrapper -->
		<?php if ( kiddiz_theme_option( 'enable_header_wave', false ) ) : ?>
            <div class="wave-saperator top-wave">
                <?php echo kiddiz_get_svg( array( 'icon' => 'cloud-border' ) ); ?>
            </div>
        <?php endif; ?>
		</header><!-- #masthead -->
	<?php }
endif;
add_action( 'kiddiz_header_ends_action', 'kiddiz_center_header_ends', 10 );

if ( ! function_exists( 'kiddiz_render_slider_section' ) ) :
  /**
   * Start slider section
   *
   * @return string slider content
   * @since Kiddiz 1.0.0
   *
   */
   function kiddiz_render_slider_section( $content_details = array() ) {
        if ( empty( $content_details ) )
            return;

        $slider_control = kiddiz_theme_option( 'slider_arrow' );
        $slider_auto_slide = kiddiz_theme_option( 'slider_auto_slide' );
        $slider_btn_label = kiddiz_theme_option( 'slider_btn_label', esc_html__( 'Learn More', 'kiddiz-center' ) );
        ?>
    	<div id="custom-header">
            <div class="section-content banner-slider center-align with-bg" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1200, "dots": false, "arrows":<?php echo $slider_control ? 'true' : 'false'; ?>, "autoplay": <?php echo $slider_auto_slide ? 'true' : 'false'; ?>, "fade": true, "draggable": true }'>
                <?php foreach ( $content_details as $content ) : ?>
                    <div class="custom-header-content-wrapper slide-item">
                        <?php if ( ! empty( $content['image'] ) ) : ?>
                            <img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>">
                        <?php endif; ?>
                        <div class="overlay"></div>
                        <div class="wrapper">
                            <div class="custom-header-content">
                                <?php if ( ! empty( $content['title'] ) ) : ?>
                                    <h2><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                <?php endif; 

                                if ( ! empty( $content['excerpt'] ) ) : ?>
                                    <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                <?php endif; 

                                if ( ! empty( $slider_btn_label ) ) : ?>
                                    <div class="read-more">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>">
                                            <?php echo esc_html( $slider_btn_label ); ?>
                                            <span class="screen-reader-text"><?php echo esc_html( $content['title'] ); ?></span>
                                        </a>
                                    </div>
                                <?php endif; ?>
                            </div><!-- .custom-header-content -->
                        </div>
                    </div><!-- .custom-header-content-wrapper -->
                <?php endforeach; ?>
            </div><!-- .wrapper -->
            <?php if ( kiddiz_theme_option( 'enable_slider_wave', false ) ) : ?>
                <div class="wave-saperator bottom-wave">
                    <?php echo kiddiz_get_svg( array( 'icon' => 'cloud-border' ) ); ?>
                </div>
            <?php endif; ?>
        </div><!-- #custom-header -->
    <?php 
    }
endif;

if ( ! function_exists( 'kiddiz_render_introduction_section' ) ) :
  /**
   * Start introduction section
   *
   * @return string introduction content
   * @since Kiddiz 1.0.0
   *
   */
   function kiddiz_render_introduction_section( $content_details = array() ) {
        $read_more = kiddiz_theme_option( 'introduction_btn_label', esc_html__( 'Explore Us', 'kiddiz-center' ) );

        if ( empty( $content_details ) )
            return;

        ?>
    	<div id="introduction" class="page-section relative left-align">
            <div class="wrapper">
                <?php foreach ( $content_details as $content ) : ?>
                    <article class="hentry design-3">
                        <div class="post-wrapper">
                            <div class="entry-container">
                                <?php if ( ! empty( $content['title'] ) ) : ?>
                                    <header class="entry-header">
                                        <h2 class="entry-title">
                                            <a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a>
                                        </h2>
                                    </header>
                                <?php endif; 

                                if ( ! empty( $content['excerpt'] ) ) : ?>
                                    <div class="entry-content">
                                        <?php echo wp_kses_post( $content['excerpt'] ); ?>
                                    </div><!-- .entry-content -->
                                <?php endif; ?>
                                <a class="more-btn" href="<?php echo esc_url( $content['url'] ); ?>">
                                    <span class="screen-reader-text"><?php echo esc_html( $content['title'] ); ?></span>
                                    <?php echo esc_html( $read_more ); ?>
                                </a>
                            </div><!-- .entry-container -->
                            <?php if ( ! empty( $content['image'] ) ) : ?>
                                <div class="featured-image">
                                    <a href="<?php echo esc_url( $content['url'] ) ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>"></a>
                                </div><!-- .featured-image -->
                            <?php endif; ?>
                        </div><!-- .post-wrapper -->
                    </article>
                <?php endforeach; ?>
            </div><!-- .wrapper -->
        </div><!-- #introduction -->
    <?php 
    }
endif;
